@@ -1,4 +1,2 @@
 //! Library that provides definitions for daemon related features in streamduck
-pub mod socket;
-pub mod core_manager;
-pub mod config;
\ No newline at end of file
+pub mod daemon_data;
